@@ -1,7 +1,10 @@
 import click
 from tabulate import tabulate
-from .. import db
-from .. import utils
+
+from yatta import db as db
+from yatta import utils as utils
+from yatta.completion_helpers import get_matching_tasks
+from yatta.config import Config
 
 
 @click.group()
@@ -13,7 +16,9 @@ def list():
 
 
 @list.command()
-@click.argument("task_name", required=False)
+@click.argument(
+    "task_name", required=False, type=click.STRING, autocompletion=get_matching_tasks
+)
 def tasks(task_name=None):
     """
     List all tasks or show info for a particular task.
@@ -21,12 +26,25 @@ def tasks(task_name=None):
     query = db.get_tasks(task_name)
     _tasks = db.query_to_df(query)
     _tasks["total"] = _tasks["total"].apply(utils.time_print)
-    print(tabulate(_tasks, headers=_tasks.columns, tablefmt="fancy_grid"))
+    print(
+        "\n"
+        + tabulate(
+            _tasks,
+            headers=_tasks.columns,
+            tablefmt=Config().get_user_value("formatting", "table_style"),
+        )
+    )
 
 
 @list.command()
 @click.argument("record_id", required=False)
-@click.option("-t", "--task", help="Task name or ID to get records from.")
+@click.option(
+    "-t",
+    "--task",
+    help="Task name or ID to get records from.",
+    type=click.STRING,
+    autocompletion=get_matching_tasks,
+)
 @click.option(
     "-m",
     "--max-entries",
@@ -43,4 +61,11 @@ def records(all, max_entries, record_id=None, task=None):
     if not all:
         _records = _records.tail(max_entries)
     _records["duration"] = _records["duration"].apply(utils.time_print)
-    print(tabulate(_records, headers=_records.columns, tablefmt="fancy_grid"))
+    print(
+        "\n"
+        + tabulate(
+            _records,
+            headers=_records.columns,
+            tablefmt=Config().get_user_value("formatting", "table_style"),
+        )
+    )
