@@ -1,8 +1,11 @@
 #!/usr/bin/env python
-import click
 import logging
-from appdirs import user_data_dir
-from .commands import track, list, edit, delete
+
+import click
+
+from yatta import utils as utils
+from yatta.commands import config, delete, edit, list, plot, start, timesheet
+from yatta.daemon import daemon_status, daemon_stop
 
 try:
     from importlib import metadata
@@ -10,7 +13,7 @@ except ImportError:  # for Python < 3.8
     import importlib_metadata as metadata
 
 APP_NAME = "yatta"
-DATA_DIR = user_data_dir(APP_NAME)
+DATA_DIR, CONFIG_DIR, CACHE_DIR = utils.get_app_dirs()
 
 CLICK_CONTEXT_SETTINGS = dict(help_option_names=["-h", "--help"],)
 
@@ -28,11 +31,32 @@ def main(log_level):
     )
 
 
+@click.command()
+def status():
+    """
+    Check status of active task.
+    """
+    daemon_status()
+
+
+@click.command()
+def stop():
+    """
+    Stop tracking the active task.
+    """
+    daemon_stop()
+
+
 # add cli commands and command groups to main
-main.add_command(track.track)
+main.add_command(start.start)
 main.add_command(list.list)
 main.add_command(edit.edit)
 main.add_command(delete.delete)
+main.add_command(plot.plot)
+main.add_command(timesheet.timesheet)
+main.add_command(config.config)
+main.add_command(status)
+main.add_command(stop)
 
 
 if __name__ == "__main__":
